modular smoke & cleanup.
src/origami/origami.lisp
Sun Jan 10 09:54:26 CET 2010 Tobias Rautenkranz <tobias@rautenkranz.ch>
* modular smoke & cleanup.
--- old-qt.examples/src/origami/origami.lisp 2014-10-05 16:45:12.000000000 +0200
+++ new-qt.examples/src/origami/origami.lisp 2014-10-05 16:45:12.000000000 +0200
@@ -1,11 +1,15 @@
;;; Pleated Hyperbolic Paraboloid
;;;
;;; Construction using the method in:
+;;;
;;; (Non)existence of Pleated Folds: How Paper Folds Between Creases
-;;; 6 Existence of Triangulated Hyperbolic Paraboloid
-;;; http://arxiv.org/abs/0906.4747
;;;
-;;; depends on: :qt.examples tri.lisp :cl-opengl :cl-glu
+;;; Erik D. Demaine, Martin L. Demaine, Vi Hart, Gregory N. Price,
+;;; Tomohiro Tachi
+;;;
+;;; http://arxiv.org/abs/0906.4747
+;;;
+;;; Section 6: Existence of Triangulated Hyperbolic Paraboloid
(in-package :qt.examples)
@@ -270,3 +274,10 @@
(cxx:tick-position rings) qt:slider.+ticks-right+
(cxx:tick-interval rings) 10)))
(cxx:set-layout origami layout)))
+
+(defun origami ()
+ "OpenGL Pleated Hyperbolic Paraboloid"
+ (qt:with-app ()
+ (let ((origami (make-instance 'origami)))
+ (cxx:show origami)
+ (qt:exec))))
@@ -1,11 +1,15 @@
-;;; Pleated Hyperbolic Paraboloid
+;;; OpenGL Pleated Hyperbolic Paraboloid
;;;
;;; Construction using the method in: